LocalClientBuilder

Struct LocalClientBuilder 

pub struct LocalClientBuilder<F: Future<Output = ()> + Send + 'static, SA: ToSocketAddrs> { /* private fields */ }

Implementations

Source

impl<F: Future<Output = ()> + Send + 'static, SA: ToSocketAddrs> LocalClientBuilder<F, SA>

pub fn new() -> LocalClientBuilder<F, SA>

pub fn event_handler( self, event_handler: fn(ConnectionEvent<LocalClient>) -> F, ) -> Result<Self>

pub fn addr(self, addr: SA) -> Result<Self>

pub async fn connect(self) -> Result<LocalClientHandle>

Connect to the target address.

Connects to the specified address using TCP. It blocks until a connection has been made but does not block while the connection is alive.